#include "command.h"

#include <stdio.h>

//=============================================

//===================================================================//
// LCD Command Write Subroutine //
//===================================================================//
void LCD_CmdWrite(uint8_t cmdReg, uint8_t cmdData)
{

	LCD_ChkBusy();
	LCD_DATA = cmdReg;
	CLR_CS; //RA8803/8822 Chip Enable.
	SET_RD;
	CLR_RS; // RS = 0;
	CLR_WR; // WR = 0;
	delay(0); //min 400nS delay required
	SET_WR; // WR = 1;

	LCD_DATA = cmdData;
	CLR_WR; // WR = 0;
	delay(0); //min 400nS delay required
	SET_WR; // WR = 1;
	SET_RS; // RS = 1;
	SET_CS; //RA8803/8822 Chip Disable.
		//delay(1);
}

//====================================================================//
// //
//====================================================================//
void LCD_Initial(void)
{
	LCD_CmdWrite(0x00, 0xC5); // LCD Control Register(WLCR)
				//1011 0101
				//XXX1 XXXX
				//|||  ||||---	Inverse Mode Selection
				//|||  |||		  0: Inverse Full Screen. It will cause the display to be inverted
				//|||  |||		>>1: Normal Display
				//|||  |||
				//|||  |||----	Blink Mode Selection
				//|||  ||		>>0: Normal Display
				//|||  ||		  1: Blink Full Screen. The blink time is set by BTMR
				//|||  ||
				//|||  ||-----	Set Display On/Off Selection
				//|||  |		  0: Display Off
				//|||  |		>>1: Display On
				//|||  |
				//|||  |------	Display Mode Selection
				//||| 			>>0: Graphical Mode: The written data will be treated as a bit-map pattern
				//||| 			  1: Character Mode: The written data will be treated as a GB/BIG/ASCII code
				//||| 			  
				//||| 			  
				//|||---------	Software Reset
				//||			>>0: Normal Operation
				//||			  1: Reset all registers except flushing RAM
				//||----------	Power Mode
				//				  00: Off Mode. When RA8803/8822 is in off mode, all functions enter 
				//						power-off mode, except the wake-up trigger block. If wake-up
				//						event occurs, the controller will wake up and return to Normal mode.
				//				>>11: Normal Mode. All of the controller functions are available in this mode

	LCD_CmdWrite(0x01, 0xF3); // Misc.Register(MIR)
				//0101 0011
				//1X1X 00XX
				// | |   ||---	Clock Speed Selection
				// | |   		  00: 3MHz 
				// | |   		  01: 4MHz 
				// | |   		  10: 8MHz 
				// | |   		>>11: 12MHz
				// | | 
				// | |--------	The Output Pins -- Interrupt (INT) and Busy Polarity
				// | 			  0: Set Active Low
				// | 			>>1: Set Active High
				// |
				// |----------	Clock Output (Pin CLK_OUT) Control
				// 				  0: Disable
				// 				>>1: Enable
				//
				//
	LCD_CmdWrite(0x02, 0x10); // Advance Power Setup Register(APSR)
	LCD_CmdWrite(0x03, 0x80); // Advance Display Setup Register(ADSR)
				//1000 0000
				//1000 XXXX
				//      |||---	Common or Segment Scrolling Selection
				//      ||		>>0: Common Scrolling
				//      ||		  1: Segment Scrolling
				//      ||
				//      ||----	Segment Auto Scrolling
				//      |		>>0: Disable
				//      |		  1: Enable
				//      |
				//      |-----	Common Auto Scrolling
				//      		>>0: Disable
				//      		  1: Enable

	LCD_CmdWrite(0x10, 0x28); // Cursor Control Register(CCR)
				//0010 1000
				//XXXX XXXX
				//|||| ||||---	Cursor Width
				//|||| |||		>>0: Cursor is fixed at one byte width
				//|||| |||		  1: Cursor width is auto adjusted by input data. When half sized
				//|||| |||			font is used, the width is one bit. When full sized font
				//|||| |||			is used, the width is two bits.
				//|||| |||
				//|||| |||----	Cursor Blinking
				//|||| ||		>>0: Normal
				//|||| ||		  1: Blink Cursor. The blink time is determined by BTMR (CMD 80h)
				//|||| ||
				//|||| ||-----	Cursor Display
				//|||| |		>>0: Set Cursor Display Off
				//|||| |		  1: Set Cursor Display On
				//|||| |
				//|||| |------	Auto Increase Cursor Position in Writing DDRAM Operation
				//||||			  0: Disable
				//|||| 			>>1: Enable (Auto Increase)
				//|||| 
				//||||--------	Bold Font (character mode only)
				//|||			>>0: Normal Font
				//|||			  1: Bold Font
				//|||
				//|||---------	Store Current Data to DDRAM
				//||			  0: Store Current Data to DDRAM Inversely
				//||			>>1: Store Current Data to DDRAM Directly
				//||
				//||----------	Chinese/English Character Alignment (character mode only)
				//|				  0: Disable
				//|				>>1: Enable
				//|
				//|-----------	Auto Increase Cursor Position in Reading DDRAM Operation
				//				>>0: Disable
				//				>>1: Enable (Auto Increase)
				
	LCD_CmdWrite(0x11, 0x10); // Distance of Word or Lines Register(DWLR)
				//0001 0000
				//XXXX XXXX
				//|||| ||||---	Set Line Distance
				//||||			  0000: 1 pixel between lines
				//||||			>>0001: 2 pixels between lines
				//||||			  0010: 3 pixels between lines
				//||||				.
				//||||				.
				//||||				.
				//||||			  1111: 16 pixels between lines
				//||||
				//||||--------	Set Cursor Height
				//				  0000: 1 pixel in width
				//				>>0001: 2 pixels in width
				//				  0010: 3 pixels in width
				//					.
				//					.
				//					.
				//				  1111: 16 pixels in width

	LCD_CmdWrite(0x12, 0x91); // Memory Access Mode Register(AWRR)
				//1001 0001
				//XXXX XXXX
				//|||| ||||---	MPU Read/Write Layer Selection
				//|||| ||		  00: Access Page0 (512B SRAM) Display Data Ram
				//|||| ||		  01: Access Page1 (9.6kB SRAM) Display Data Ram
				//|||| ||		  10: Access Page2 (9.6kB SRAM) Display Data Ram
				//|||| ||		  11: Access Page1 and Page2 Display Data RAM at the same time
				//|||| ||
				//|||| ||-----	Two Layer Mode Selection
				//||||          >>00: Page 1 RAM "OR" Page 2 RAM
				//||||            01: Page 1 RAM "XOR" Page 2 RAM
				//||||            10: Page 1 RAM "NOR" Page 2 RAM
				//||||            11: Page 1 RAM "AND" Page 2 RAM
				//|||| 
				//||||--------	Display Layer Selection
				//|				  000: Gray Mode. In this mode, each pixel of gray depends on the
				//|						value of Page1 & Page2 
				//|                        Page 1 | Page 2 | Gray
				//|                       --------+--------+--------
				//|                          0    |   0    | Level 1
				//|                          1    |   0    | Level 2
				//|                          0    |   1    | Level 3
				//|                          1    |   1    | Level 4
				//|
				//|				>>001: Only Show Page1
				//|				  010: Only Show Page2
				//|				  011: Show Two Layer Mode. The display rule depends on Bit2 and Bit3 above
				//|				  110: Extension Mode(1), the panel will show both Page1 and Page2. The RA8803 
				//|						is available for 640x240 dots panel, and RA8822 for 480x160 dots panel.
				//|				  111: Extension Mode(1), the panel will show both Page1 and Page2. The RA8803 
				//|						is available for 320x480 dots panel, and RA8822 for 240x320 dots panel.
				//|						
				//|-----------	Cursor Auto Shifting Direction (graphic mode only)
				//				  0: Vertical first then Horizontal
				//				>>1: Horizontal first then Vertical
				


	//Registers 20h, 30h, 40h, and 50h specify the active window for writing characters to the display.
	//If the cursor goes past the specified window, then it will automatically jump to the next 
	//row/column specified by the active window. 
	LCD_CmdWrite(0x20, 0x13); // Active Window Right Register(AWRR)
				//0001 0011
				//00XX XXXX
				//  || ||||---  Active Window Right Position
				//                00 0000: end of Active Window is 1 character to the right 
				//                .
				//                .
				//              >>01 0011: end of Active Window is 20 characters to the right 
				//                .
				//                .
				//                11 1111: end of Active Window is 64 characters to the right 
				
	LCD_CmdWrite(0x30, 0x9F); // Active Window Bottom Register(AWBR)
				//1001 1111
				//XXXX XXXX
				//|||| ||||---  Active Window Right Position
				//                0000 0000: end of Active Window is 1 pixel from the top
				//                .
				//                .
				//              >>1001 1111: end of Active Window is 160 pixels from the top
				//                .
				//                .
				//                1111 1111: end of Active Window is 256 pixels from the top

	LCD_CmdWrite(0x40, 0x00); // Active Window Left Register(AWLR)
				//0000 0000
				//00XX XXXX
				//  || ||||---  Active Window Right Position
				//              >>00 0000: start of Active Window is 1 character to the right 
				//                .
				//                .
				//                01 0011: start of Active Window is 20 characters to the right 
				//                .
				//                .
				//                11 1111: start of Active Window is 64 characters to the right 

	LCD_CmdWrite(0x50, 0x00); // Active Window Top Register(AWTR)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Active Window Right Position
				//              >>0000 0000: start of Active Window is 1 pixel from the top
				//                .
				//                .
				//                1001 1111: start of Active Window is 160 pixels from the top
				//                .
				//                .
				//                1111 1111: start of Active Window is 256 pixels from the top

	//Registers 21h, 31h, 41h, and 51h specify the Display Window to the controller. These are the
	//actual dimensions of the display, not just the working area as the above four commands are for.
	LCD_CmdWrite(0x21, 0x13); // Display Window Right Register(DWRR)
				//0001 0011
				//00XX XXXX
				//  || ||||---  Active Window Right Position
				//                00 0000: end of Display Window is 1 character to the right 
				//                .
				//                .
				//              >>01 0011: end of Display Window is 20 characters to the right 
				//                .
				//                .
				//                11 1111: end of Display Window is 64 characters to the right 

	LCD_CmdWrite(0x31, 0x9F); // Display Window Bottom Register(DWBR)
				//1001 1111
				//XXXX XXXX
				//|||| ||||---  Active Window Right Position
				//                0000 0000: end of Display Window is 1 pixel from the top
				//                .
				//                .
				//              >>1001 1111: end of Display Window is 160 pixels from the top
				//                .
				//                .
				//                1111 1111: end of Display Window is 256 pixels from the top

	LCD_CmdWrite(0x41, 0x00); // Display Window Left Register(DWLR)
				//0000 0000
				//00XX XXXX
				//  || ||||---  Active Window Right Position
				//              >>00 0000: start of Display Window is 1 character to the right 
				//                .
				//                .
				//                01 0011: start of Display Window is 20 characters to the right 
				//                .
				//                .
				//                11 1111: start of Display Window is 64 characters to the right 

	LCD_CmdWrite(0x51, 0x00); // Display Window Top Register(DWTR)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Active Window Right Position
				//              >>0000 0000: start of Display Window is 1 pixel from the top
				//                .
				//                .
				//                1001 1111: start of DIsplay Window is 160 pixels from the top
				//                .
				//                .
				//                1111 1111: start of Display Window is 256 pixels from the top

	LCD_CmdWrite(0x60, 0x00); // Cursor Position X Register(CPXR)
				//0000 0000
				//00XX XXXX
				//  || ||||---  Cursor Position of Segment
				//              >>00 0000: Cursor is 1 character to the right of the Active Window
				//                .
				//                .
				//                01 0011: Cursor is 20 characters to the right of the Active Window
				//                .
				//                .
				//                11 1111: Cursor is 64 characters to the right of the Active Window

	LCD_CmdWrite(0x61, 0x00); // Begin Segment Position Register(BGSG)
				//0000 0000
				//0000 0000
	LCD_CmdWrite(0x70, 0x00); // Cursor Position Y Register(CPYR)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Cursor Position of Segment
				//              >>0000 0000: Cursor is 1 pixel down from the top of the Active Window
				//                .
				//                .
				//                0001 0011: Cursor is 20 pixels down from the top of the Active Window
				//                .
				//                .
				//                1111 1111: Cursor is 256 pixels down from the top of the Active Window

	LCD_CmdWrite(0x71, 0x00); // Shift action range, Begin Common Register(BGCM)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Common Start position of Scrolling Mode
				//                0000 0000: start position for shifting will start 1 pixel from the top of the active display
				//                .
				//                .
				//                1111 1111: start position for shifting will start 256 pixels from the top of the active display

	LCD_CmdWrite(0x72, 0xEF); // Shift action range, End Common Register(EDCM)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Common Ending position of Scrolling Mode
				//                0000 0000: ending position for shifting will start 1 pixel from the top of the active display
				//                .
				//                .
				//                1111 1111: ending position for shifting will start 256 pixels from the top of the active display
	LCD_CmdWrite(0x80, 0x33); // Blink Time Register(BTMR)
				//0011 0011
				//XXXX XXXX
				//|||| ||||---  Cursor Blinking Time - Blinking Time = Bit[7..0] x (1/Frame_Rate) 

	LCD_CmdWrite(0x81, 0x00); // Frame Rate Polarity Change at Common_FA Register(FDCA)
				//0000 0000
	LCD_CmdWrite(0x91, 0x00); // Frame Rate Polarity Change at Common_FB Register(FDCB)
				//0000 0000
	LCD_CmdWrite(0x90, 0x04); // Shift Clock Control Register(SCCR)
				//0000 0100
				//XXXX XXXX
				//|||| ||||---  Shift Clock Cycle
				//              Set per the following calculations:
				//
				//              SCCR = (SCLK x DW) / (Seg x Com x FRM)
				//              SCLK: RA8803/8822 System Clock (Hz)
				//              DW: Bus Width of LCD Driver (Bit)
				//              Seg: Segment Number of LCD Panel (Pixel)
				//              Com: Common Number of LCD Panel (Pixel)
				//              FRM: Frame Rate of LCD Panel (Hz)
				//              
				//              Note:
				//              SYS_DW=0, if LCD Data Bus is 4bit. SCCR must be >= 4.
				//              SYS_DW=1, if LCD Data Bus is 8bit. SCCR must be >= 2.

	LCD_CmdWrite(0xA0, 0x11); // Interrupt Setup & Status Register(FRCB)
				//0001 0001
				//XXXX XXXX
				//|||| ||||---  Register[B1h] INTY Event Mask
				//|||| |||        0: Disable INTY Interrupt
				//|||| |||      >>1: Enable INTY Interrupt
				//|||| |||      
				//|||| |||----  Register[B0h] INTX Event Mask
				//|||| ||       >>0: Disable INTX Interrupt
				//|||| ||         1: Enable INTX Interrupt
				//|||| ||       
				//|||| ||-----  Touch Panel Interrupt Mask
				//|||| |        >>0: Don't generate interrupt output if touch panel was detected
				//|||| |          1: Generate interrupt output if touch panel was detected
				//|||| |        
				//|||| |------  Key Scan Interrupt Mask
				//||||          >>0: Disable Key Scan Interrupt
				//||||            1: Enable Key Scan Interrupt
				//||||          
				//||||--------  Cursor Row Status
				//|||             0: The Cursor Row is not equal to INTY
				//|||           >>1: The Cursor Row is equal to INTY
				//|||           
				//|||---------  Cursor Column Status
				//||            >>0: The Cursor Column is not equal to INTX
				//||              1: The Cursor Column is equal to INTX
				//||            
				//||----------  Touch Panel Detect
				//|             >>0: Touch Panel Untouched
				//|               1: Touch Panel Touched
				//|             
				//|-----------  Key Scan Interrupt Flag
				//              >>0: Key Scan doesn't detext key input
				//                1: Key Scan detects key input

	LCD_CmdWrite(0xA1, 0x00); // Key Scan Control Register(KSCR)
				//0000 0000
				//XXXX 0XXX
				//||||  |||---  Key Scan Frequency
				//||||          >>000: 2 x FRM
				//||||            001: 4 x FRM
				//||||            010: 8 x FRM
				//||||            011: 16 x FRM
				//||||            100: 32 x FRM
				//||||            101: 64 x FRM
				//||||            110: 128 x FRM
				//||||            111: 256 x FRM
				//||||          
				//||||--------  Key Scan Data Sampling Times
				//||           >>00: 2h
				//||             01: 4h
				//||             10: 8h
				//||             11: 16h
				//||           
				//||----------  Key Scan Matrix Selection
				//|            >>0: 8x8 Matrix
				//|              1: 4x4 matrix
				//|            
				//|-----------  Key Scan Enable Bit
				//              >>0: Disable
				//                1: Enable

	LCD_CmdWrite(0xA2, 0x00); // Key Scan Data Register(KSDR)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Key Scan KC[7~0] Output

	LCD_CmdWrite(0xA3, 0x00); // Key Scan Data Expand Register(KSER)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Key Scan KC[7~0] Input

	LCD_CmdWrite(0xB0, 0x27); // Interrupt Column Setup Register(INTX)
				//0010 0111
				//00XX XXXX
				//  || ||||---  Column Address of Interrupt
				//                If the CPXR(60h) == INTX, an interrupt has occurred

	LCD_CmdWrite(0xB1, 0xEF); // Interrupt Row Setup Register(INTY)
				//1110 1111
				//XXXX XXXX
				//|||| ||||---  Column Address of Interrupt
				//                If the CPYR(70h) == INTY, an interrupt has occurred

	LCD_CmdWrite(0xC0, 0xD0); // Touch Panel Control Register(TPCR)
				//1101 0000
				//XX0X XXXX
				//|| | ||||---  Switch Control of Panel
				//|| | |||      >>0: SW0 OFF
				//|| | |||        1: SW0 ON
				//|| | |||      
				//|| | |||----  Switch Control of Panel
				//|| | ||       >>0: SW1 OFF
				//|| | ||         1: SW1 ON
				//|| | ||       
				//|| | ||-----  Switch Control of Panel
				//|| | |        >>0: SW2 OFF
				//|| | |          1: SW2 ON
				//|| | |        
				//|| | |------  Switch Control of Panel
				//|| |          >>0: SW3 OFF
				//|| |            1: SW3 ON
				//|| |          
				//|| |--------  Touch Panel Scan
				//||              0: Enable
				//||            >>1: Disable
				//||            
				//||----------  Touch Panel Data Output Control
				//|               0: Disable the Touch Panel Data Output
				//|             >>1: Enable to Touch Panel Data Output
				//|             
				//|-----------  ADC Data Convert State
				//                0: Convert Incomplete
				//              >>1: Convert Complete

	LCD_CmdWrite(0xC1, 0x2A); // ADC Status Register(ADCS)
				//0010 1010
				//XX10 XX10     
				//||   ||-----  ADC Convert Speed
				//||              00: SCLK/32
				//||              01: SCLK/64
				//||            >>10: SCLK/128
				//||              11: SCLK/256
				//||            
				//||----------  Touch Event Indicate
				//|             >>0: Un-Touched
				//|               1: Touched
				//|             
				//|-----------  ADC Data Convert State
				//              >>0: Convert Incomplete
				//                1: Convert Complete

	LCD_CmdWrite(0xC8, 0x80); // Touch Panel Segment High Byte Data Register(TPXR)
				//1000 0000
				//XXXX XXXX
				//|||| ||||---  Touch Panel Segment Data Bit[9..2]

	LCD_CmdWrite(0xC9, 0x80); // Touch Panel Common High Byte Data Register(TPYR)
				//1000 0000
				//XXXX XXXX
				//|||| ||||---  Touch Panel Segment Data Bit[9..2]

	LCD_CmdWrite(0xCA, 0x00); // Touch Panel Segment/Common Low Byte Data Register(TPZR)
				//0000 0000
				//XX00 XXXX     
				//||   ||-----  Touch Panel Comon Data Bit[1..0]
				//||            
				//||----------  Touch Panel Segment Data Bit[1..0]

	LCD_CmdWrite(0xD0, 0x0C); // LCD Contrast Control Register (LCCR)
				//0010 1000
				//X01X XXXX
				//|  | ||||---  DAC Driving Current
				//|             0 0000: 0uA +/- .2uA 
				//|             .
				//|             .
				//|             1 1111: 540uA +/- 140uA
				//|             
				//|-----------  DAC Function
				//              0: Enable
				//              1: Disable

	LCD_CmdWrite(0xE0, 0x00); // Pattern Data Register(PNTR)
				//0000 0000
				//XXXX XXXX
				//|||| ||||---  Data Written to DDRAM
				//              When REG[F0h] bit3 is '1', it will read the data from Register E0h and fill the whole DDRAM.
				//              After the whold DDRAM is filled, bit3 will become '0'.

	LCD_CmdWrite(0xF0, 0x90); // Font Control Register(FCR)
				//1001 0000
				//XXXX XXXX
				//|||| ||||---  ASCII Block Select
				//|||| ||       >>00: Map to ASCII block 0, Latin_1
				//|||| ||         01: Map to ASCII block 1, Latin_2
				//|||| ||         10: Map to ASCII block 2, Latin_3
				//|||| ||         11: Map to ASCII block 3, Latin_4
				//|||| ||       
				//|||| ||-----  ASCII Code Selection
				//|||| |        >>0: All input data will be decoded as ASCII (00h-FFh)
				//|||| |          1: The controller will check the first byte of data first. If the first byte
				//|||| |				is 00h-9Fh, then the data will be regarded as ASCII (half-sized font, 8bit).
				//|||| |				If the first byte is A0h-FFh, then the data will be regarded as 
				//|||| |				GB/BIG5 font (full-sized font, 16bit).
				//|||| |        
				//|||| |------ Fill PNTR Data to DDRAM 
				//||||          >>0: No Action
				//||||            1: Fill Data to DDRAM Enable
				//||||          
				//||||--------  Select Font ROM Type
				//||              00: Select GB font ROM (256kB, Mode0)
				//||            >>01: Select BIG5 font ROM (512kB, Mode1)
				//||              10: Support GB font ROM (512kB, Mode2)
				//||            
				//||----------  When "Select Font ROM Type" is set to 00, this can be used to select the upper/lower part
				//|             of the 256kB ROM
				//|             >>0: Select upper part of 256kB ROM
				//|               1: Select lower part of 256kB ROM
				//|             
				//|-----------  Font ROM Transfer Circuit
				//                0: Bypass
				//              >>1: Transfer

	LCD_CmdWrite(0xF1, 0x0F); // Font Size Control Register
				//0000 1111
				//XXXX 1111   
				//||||--------  Set Character Vertical Size
				//||            >>00: One Time
				//||              01: Two Times
				//||              10: Three Times
				//||              11: Four Times
				//||            
				//||----------  Set Character Horizon Size
				//              >>00: One Time
				//                01: Two Times
				//                10: Three Times
				//                11: Four Times

}
void LCD_Clear(void)
{
	unsigned char READ_REG;
	LCD_CmdWrite(0xE0, 0x00);
	//READ_REG = LCD_CmdRead(0xF0);
	//READ_REG = 0x90;
	//READ_REG &= 0xF7;
	//READ_REG |= 0x08;

	//Set bit 3 of 0xF0 REG to fill PNTR data to DDRAM
	LCD_CmdWrite(0xF0, 0x98);
}
void LCD_Fill(uint8_t pattern)
{
	unsigned char READ_REG;
	LCD_CmdWrite(0xE0, pattern);
	//READ_REG = LCD_CmdRead(0xF0);
	//READ_REG = 0x90;
	//READ_REG &= 0xF7;
	//READ_REG |= 0x08;

	//Set bit 3 of 0xF0 REG to fill PNTR data to DDRAM
	LCD_CmdWrite(0xF0, 0x98);
}
void LCD_DataWrite(unsigned char WrData)
{
	LCD_DATA = WrData;
	CLR_CS; //RA8803/8822 Chip Enable.
	SET_RD; //
	SET_RS; // RS = 1;

	CLR_WR; // WR = 0;
	delay(0);
	SET_WR; // WR = 1;
	SET_RS; // RS = 1;
	SET_CS; //RA8803/8822 Chip Disable.
}
void PrintStr(char *ptr, int delay_time)
{
	uint8_t i = 0;
	while (ptr[i] != '\0')
	{
		//write out a byte at a time
		LCD_DataWrite(ptr[i]);
		i++;
		delay(delay_time);
	}
}
unsigned char LCD_CmdRead(unsigned char cmdReg)
{
	unsigned char REG_Read;
	LCD_ChkBusy();
	LCD_DATA = cmdReg;
	CLR_CS; //RA8803/8822 Chip Enable.
	SET_RD; 
	CLR_RS; // RS = 0;
	CLR_WR; // WR = 0;
	delay(0);
	SET_WR; // WR = 1;


	LCD_ChkBusy();
	LCD_DATA = 0xff;
	DDRD = 0x00;
	delay(0);
	CLR_RD; // RD = 0;
	delay(0);
	REG_Read = LCD_DATA;
	SET_RD; // RD = 1;
	SET_RS; // RS = 1;
	SET_CS; //RA8803/8822 Chip Disable.
	DDRD = 0xff;
	return REG_Read;
}
void LCD_ChkBusy(void)
{
	delay(10);
	do
	{
	} while (PINB5 == 1);
}

 void GotoXY(unsigned char x1, unsigned char y1)
{
	LCD_CmdWrite(0x60, x1); // Active Window Top Register(AWTR)
	LCD_CmdWrite(0x70, y1); // Active Window Top Register(AWTR)
}